@@ -84,7 +84,7 @@ def up(
         release = getattr(settings, "SENTRY_RELEASE", "")
         _envs += [f"SENTRY_DSN={settings.SENTRY_DSN}", f"RELEASE={release}"]
 
-    if hasattr(settings, "CONTAINER_LOG_LEVEL"):
+    if hasattr(settings, "CONTAINER_LOG_LEVEL") and "LOG_LEVEL" not in envs:
         _envs += [f"LOG_LEVEL={settings.CONTAINER_LOG_LEVEL}"]
 
     cmd = f"python service.py {settings.REDIS_HOST} {model_config} {sim_uid} {sim_ref_datetime} {end_time} {duration} {start_mode} {pause_timeout} {max_rate} {clean_up_files}" # noqa
